@@ -1,5 +1,4 @@
-#!/usr/bin/env python
-# -*- coding:utf-8 -*-
+#!/usr/bin/env python3
 """
 Generate a sample rendering of the base font.
 """
@@ -16,11 +15,11 @@ background = Image.new("RGBA", (WIDTH, HEIGHT), (255, 255, 255))
 foreground = Image.new("RGBA", (WIDTH, HEIGHT), (255, 255, 255, 0))
 draw_b = ImageDraw.Draw(background)
 draw_f = ImageDraw.Draw(foreground)
-size_font = ImageFont.truetype('./3270Medium.otf', size=15)
+size_font = ImageFont.truetype('./build/3270Medium.otf', size=15)
 y = 0
 
 for size in range(15, 55, 5):
-    sample_font = ImageFont.truetype('./3270Medium.otf', size=size)
+    sample_font = ImageFont.truetype('./build/3270Medium.otf', size=size)
     offset = size * .7
     y += offset
     # Draw the background reference lines.
@@ -32,4 +31,4 @@ for size in range(15, 55, 5):
 
 img = Image.alpha_composite(background, foreground)
 
-img.save("3270Medium_sample.png")
+img.save("build/3270Medium_sample.png")
