@@ -12,6 +12,12 @@ misc_glyphs = """
 Other miscellaneous glyphs: ™●⌘⏎⬇⬆✔✼✎✘‘’⚓
 """
 
+apl_set = """
+The APL set: ⌶⌷⌸⌹⌺⌻⌼⌽⌾⌿⍀⍁⍂⍃⍄⍅⍆⍇⍈⍉⍊⍋⍌⍍⍎⍏⍐⍑⍒⍓⍔⍕⍖⍗⍘⍙⍚⍛⍜⍝⍞⍟⍠⍡⍢⍣⍤⍥⍦⍧⍨⍩⍪⍫⍬⍭⍮⍯⍰⍱⍲⍳⍴⍵⍶⍷
+⍸⍹⍺
+"""
+
 if __name__ == '__main__':
     print(boxes)
     print(misc_glyphs)
+    print(apl_set)
